.. image:: https://user-images.githubusercontent.com/11671536/51515070-22241c00-1dc7-11e9-90d5-832f3caa5c70.png

"A Pandas-Centric ObsPy_ Expansion Pack"

|Build Status| |Coverage| |Version Status| |Supported Versions| |Style| |Downloads| |Licence|

Documentation_

Code_

License_

About_

.. _About: https://github.com/niosh-mining/about
.. _ObsPy: https://github.com/obspy/obspy
.. _Documentation: https://niosh-mining.github.io/obsplus/
.. _Code: https://github.com/niosh-mining/obsplus
.. _License: https://choosealicense.com/licenses/lgpl-3.0/

.. |Build Status| image:: https://travis-ci.org/niosh-mining/obsplus.svg?branch=master
   :target: https://travis-ci.org/niosh-mining/obsplus

.. |Coverage| image:: https://coveralls.io/repos/github/niosh-mining/obsplus/badge.svg?branch=master
   :target: https://coveralls.io/github/niosh-mining/obsplus?branch=master

.. |Supported Versions| image:: https://img.shields.io/pypi/pyversions/obsplus.svg
   :target: https://pypi.python.org/pypi/obsplus

.. |Licence| image:: https://www.gnu.org/graphics/lgplv3-88x31.png
   :target: https://www.gnu.org/licenses/lgpl.html

.. |Version Status| image:: https://img.shields.io/pypi/v/obsplus.svg
   :target: https://pypi.python.org/pypi/obsplus/

.. |Style| image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/ambv/black
   :alt: Code style: black

.. |Downloads| image:: https://pepy.tech/badge/obsplus
   :target: https://pepy.tech/project/obsplus
   :alt: Downloads

